==> owncloud-10.0.7.tgz: owncloud/apps/files/l10n/fr.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Espace de stockage temporairement indisponible",
    "Storage invalid" : "Support de stockage non valable",
    "Unknown error" : "Erreur Inconnue ",
    "All files" : "Tous les fichiers",
    "Saved" : "Sauvegardé",
    "There was an error saving" : "Il y a eu une erreur durant la sauvegarde",
    "File could not be found" : "Ce fichier n'a pu être trouvé.",
    "Home" : "Mes fichiers",
    "Close" : "Fermer",
    "Favorites" : "Favoris",
    "Could not create folder \"{dir}\"" : "Impossible de créer le dossier \"{dir}\"",
    "Upload cancelled." : "Envoi annulé.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Impossible d'envoyer {filename} car il s'agit d'un répertoire ou d'un fichier de taille nulle",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Espace libre insuffisant : vous tentez d'envoyer {size1} mais seulement {size2} sont disponibles",
    "Target folder \"{dir}\" does not exist any more" : "Le dossier de destination « {dir} » n'existe plus",
    "Not enough free space" : "Pas assez d'espace libre",
    "Uploading..." : "Téléversement en cours…",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} sur {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "L'envoi du fichier est en cours. Quitter cette page maintenant annulera l'envoi du fichier.",
    "Actions" : "Actions",
    "Download" : "Télécharger",
    "Rename" : "Renommer",
    "Delete" : "Supprimer",
    "Disconnect storage" : "Déconnecter ce support de stockage",
    "Unshare" : "Ne plus partager",
    "Could not load info for file \"{file}\"" : "Impossible de charger les informations pour le fichier \"{file}\"",
    "Files" : "Fichiers",
    "Details" : "Détails",
    "Select" : "Sélectionner",
    "Pending" : "En attente",
    "Unable to determine date" : "Impossible de déterminer la date",
    "Invalid path" : "Chemin non valide",
    "This operation is forbidden" : "Cette opération est interdite",
    "This directory is unavailable, please check the logs or contact the administrator" : "Ce répertoire n'est pas disponible. Consultez les logs ou contactez votre administrateur",
    "Could not move \"{file}\", target exists" : "Impossible de déplacer \"{file}\", la cible existe",
    "Could not move \"{file}\"" : "Impossible de déplacer \"{file}\"",
    "{newName} already exists" : "{newName} existe déjà",
    "Could not rename \"{fileName}\", it does not exist any more" : "Impossible de renommer \"{file}\", il n'existe plus",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Le nom \"{targetName}\" est déjà utilisé dans le dossier \"{dir}\". Merci de choisir un nom différent.",
    "Could not rename \"{fileName}\"" : "Impossible de renommer \"{fileName}\"",
    "Could not create file \"{file}\"" : "Impossible de créer le fichier \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Impossible de créer le fichier \"{file}\" car il existe déjà",
    "Could not create folder \"{dir}\" because it already exists" : "Impossible de créer le dossier \"{dir}\" car il existe déjà",
    "Error deleting file \"{fileName}\"." : "Erreur à la suppression du fichier \"{fileName}\".",
    "Name" : "Nom",
    "Size" : "Taille",
    "Modified" : "Modifié",
    "_%n folder_::_%n folders_" : ["%n dossier","%n dossiers"],
    "_%n file_::_%n files_" : ["%n fichier","%n fichiers"],
    "{dirs} and {files}" : "{dirs} et {files}",
    "_including %n hidden_::_including %n hidden_" : ["inclure %n caché","inclure %n cachés"],
    "You don’t have permission to upload or create files here" : "Vous n'avez pas la permission d'ajouter des fichiers ici",
    "_Uploading %n file_::_Uploading %n files_" : ["Téléversement de %n fichier","Téléversement de %n fichiers"],
    "New" : "Nouveau",
    "\"{name}\" is an invalid file name." : "\"{name}\" n'est pas un nom de fichier valide.",
    "File name cannot be empty." : "Le nom de fichier ne peut être vide.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "L'espace de stockage de {owner} est plein. Les fichiers ne peuvent plus être mis à jour ou synchronisés!",
    "Your storage is full, files can not be updated or synced anymore!" : "Votre espage de stockage est plein, les fichiers ne peuvent plus être ajoutés ou synchronisés !",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "L'espace de stockage de {owner} est presque plein ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Votre espace de stockage est presque plein ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["correspond à '{filter}'","correspondent à '{filter}'"],
    "Path" : "Chemin",
    "_%n byte_::_%n bytes_" : ["%n octet","%n octets"],
    "Favorited" : "Marqué comme favori",
    "Favorite" : "Favoris",
    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "Lien privé : seules les personnes ayant accès à ce fichier/dossier peuvent l'utiliser. Utilisez le en tant que lien permanent pour vous-même ou pour désigner des fichiers dans les partages aux autres utilisateurs.",
    "Folder" : "Dossier",
    "New folder" : "Nouveau dossier",
    "{newname} already exists" : "{newname} existe déjà",
    "Upload" : "Chargement",
    "An error occurred while trying to update the tags" : "Une erreur est survenue lors de la mise à jour des étiquettes",
    "A new file or folder has been <strong>created</strong>" : "Un nouveau fichier ou répertoire a été <strong>créé</strong>",
    "A file or folder has been <strong>changed</strong>" : "Un fichier ou un répertoire a été <strong>modifié</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limiter les notifications à ce qui concerne la création et la modification de vos <strong>fichiers favoris</strong> <em>(Flux uniquement)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Un fichier ou un répertoire a été <strong>supprimé</strong>",
    "A file or folder has been <strong>restored</strong>" : "Un fichier ou un répertoire a été <strong>restauré</strong>",
    "You created %1$s" : "Vous avez créé %1$s",
    "%2$s created %1$s" : "%2$s a créé %1$s",
    "%1$s was created in a public folder" : "%1$s a été créé dans un dossier public",
    "You changed %1$s" : "Vous avez modifié %1$s",
    "%2$s changed %1$s" : "%2$s a modifié %1$s",
    "You deleted %1$s" : "Vous avez supprimé %1$s",
    "%2$s deleted %1$s" : "%2$s a supprimé %1$s",
    "You restored %1$s" : "Vous avez restauré %1$s",
    "%2$s restored %1$s" : "%2$s a restauré %1$s",
    "Changed by %2$s" : "Modifié par %2$s",
    "Deleted by %2$s" : "Supprimé par %2$s",
    "Restored by %2$s" : "Restauré par %2$s",
    "Upload (max. %s)" : "Envoi (max. %s)",
    "File handling" : "Gestion de fichiers",
    "Maximum upload size" : "Taille max. d'envoi",
    "max. possible: " : "Max. possible :",
    "Save" : "Sauvegarder",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Avec PHP-FPM il peut se passer jusqu'à 5 minutes pour que les changements soient appliqués.",
    "Missing permissions to edit from here." : "Manque de permissions pour éditer à partir d'ici.",
    "Settings" : "Paramètres",
    "Show hidden files" : "Afficher les fichiers cachés",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Utilisez cette adresse pour <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">accéder à vos fichiers par WebDAV</a>",
    "No files in here" : "Aucun fichier",
    "Upload some content or sync with your devices!" : "Déposez du contenu ou synchronisez vos appareils !",
    "No entries found in this folder" : "Aucune entrée trouvée dans ce dossier",
    "Select all" : "Tout sélectionner",
    "Upload too large" : "Téléversement trop volumineux",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Les fichiers que vous essayez d'envoyer dépassent la taille maximale d'envoi permise par ce serveur.",
    "No favorites" : "Aucun favori",
    "Files and folders you mark as favorite will show up here" : "Les fichiers et dossiers ajoutés à vos favoris apparaîtront ici",
    "Text file" : "Fichier texte",
    "New text file.txt" : "Nouveau fichier texte.txt"
},
"nplurals=2; plural=(n > 1);");

==> owncloud-10.0.10.tgz: owncloud/apps/files/l10n/fr.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Espace de stockage temporairement indisponible",
    "Storage invalid" : "Support de stockage non valable",
    "Unknown error" : "Erreur Inconnue ",
    "All files" : "Tous les fichiers",
    "Saved" : "Sauvegardé",
    "There was an error saving" : "Il y a eu une erreur durant la sauvegarde",
    "File could not be found" : "Ce fichier n'a pu être trouvé.",
    "Home" : "Mes fichiers",
    "Close" : "Fermer",
    "Favorites" : "Favoris",
    "Could not create folder \"{dir}\"" : "Impossible de créer le dossier \"{dir}\"",
    "Upload cancelled." : "Envoi annulé.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Impossible d'envoyer {filename} car il s'agit d'un répertoire ou d'un fichier de taille nulle",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Espace libre insuffisant : vous tentez d'envoyer {size1} mais seulement {size2} sont disponibles",
    "Target folder \"{dir}\" does not exist any more" : "Le dossier de destination « {dir} » n'existe plus",
    "Not enough free space" : "Pas assez d'espace libre",
    "Uploading..." : "Téléversement en cours…",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} sur {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "L'envoi du fichier est en cours. Quitter cette page maintenant annulera l'envoi du fichier.",
    "Actions" : "Actions",
    "Download" : "Télécharger",
    "Rename" : "Renommer",
    "Delete" : "Supprimer",
    "Disconnect storage" : "Déconnecter ce support de stockage",
    "Unshare" : "Ne plus partager",
    "Could not load info for file \"{file}\"" : "Impossible de charger les informations pour le fichier \"{file}\"",
    "Files" : "Fichiers",
    "Details" : "Détails",
    "Select" : "Sélectionner",
    "Pending" : "En attente",
    "Unable to determine date" : "Impossible de déterminer la date",
    "Invalid path" : "Chemin non valide",
    "This operation is forbidden" : "Cette opération est interdite",
    "This directory is unavailable, please check the logs or contact the administrator" : "Ce répertoire n'est pas disponible. Consultez les logs ou contactez votre administrateur",
    "Could not move \"{file}\", target exists" : "Impossible de déplacer \"{file}\", la cible existe",
    "Could not move \"{file}\"" : "Impossible de déplacer \"{file}\"",
    "{newName} already exists" : "{newName} existe déjà",
    "Could not rename \"{fileName}\", it does not exist any more" : "Impossible de renommer \"{file}\", il n'existe plus",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Le nom \"{targetName}\" est déjà utilisé dans le dossier \"{dir}\". Merci de choisir un nom différent.",
    "Could not rename \"{fileName}\"" : "Impossible de renommer \"{fileName}\"",
    "Could not create file \"{file}\"" : "Impossible de créer le fichier \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Impossible de créer le fichier \"{file}\" car il existe déjà",
    "Could not create folder \"{dir}\" because it already exists" : "Impossible de créer le dossier \"{dir}\" car il existe déjà",
    "Error deleting file \"{fileName}\"." : "Erreur à la suppression du fichier \"{fileName}\".",
    "Name" : "Nom",
    "Size" : "Taille",
    "Modified" : "Modifié",
    "_%n folder_::_%n folders_" : ["%n dossier","%n dossiers"],
    "_%n file_::_%n files_" : ["%n fichier","%n fichiers"],
    "{dirs} and {files}" : "{dirs} et {files}",
    "_including %n hidden_::_including %n hidden_" : ["inclure %n caché","inclure %n cachés"],
    "You don’t have permission to upload or create files here" : "Vous n'avez pas la permission d'ajouter des fichiers ici",
    "_Uploading %n file_::_Uploading %n files_" : ["Téléversement de %n fichier","Téléversement de %n fichiers"],
    "New" : "Nouveau",
    "\"{name}\" is an invalid file name." : "\"{name}\" n'est pas un nom de fichier valide.",
    "File name cannot be empty." : "Le nom de fichier ne peut être vide.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "L'espace de stockage de {owner} est plein. Les fichiers ne peuvent plus être mis à jour ou synchronisés!",
    "Your storage is full, files can not be updated or synced anymore!" : "Votre espage de stockage est plein, les fichiers ne peuvent plus être ajoutés ou synchronisés !",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "L'espace de stockage de {owner} est presque plein ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Votre espace de stockage est presque plein ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["correspond à '{filter}'","correspondent à '{filter}'"],
    "Path" : "Chemin",
    "_%n byte_::_%n bytes_" : ["%n octet","%n octets"],
    "Favorited" : "Marqué comme favori",
    "Favorite" : "Favoris",
    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "Lien privé : seules les personnes ayant accès à ce fichier/dossier peuvent l'utiliser. Utilisez le en tant que lien permanent pour vous-même ou pour désigner des fichiers dans les partages aux autres utilisateurs.",
    "Folder" : "Dossier",
    "New folder" : "Nouveau dossier",
    "{newname} already exists" : "{newname} existe déjà",
    "Upload" : "Chargement",
    "An error occurred while trying to update the tags" : "Une erreur est survenue lors de la mise à jour des étiquettes",
    "A new file or folder has been <strong>created</strong>" : "Un nouveau fichier ou répertoire a été <strong>créé</strong>",
    "A file or folder has been <strong>changed</strong>" : "Un fichier ou un répertoire a été <strong>modifié</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limiter les notifications à ce qui concerne la création et la modification de vos <strong>fichiers favoris</strong> <em>(Flux uniquement)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Un fichier ou un répertoire a été <strong>supprimé</strong>",
    "A file or folder has been <strong>restored</strong>" : "Un fichier ou un répertoire a été <strong>restauré</strong>",
    "You created %1$s" : "Vous avez créé %1$s",
    "%2$s created %1$s" : "%2$s a créé %1$s",
    "%1$s was created in a public folder" : "%1$s a été créé dans un dossier public",
    "You changed %1$s" : "Vous avez modifié %1$s",
    "%2$s changed %1$s" : "%2$s a modifié %1$s",
    "You deleted %1$s" : "Vous avez supprimé %1$s",
    "%2$s deleted %1$s" : "%2$s a supprimé %1$s",
    "You restored %1$s" : "Vous avez restauré %1$s",
    "%2$s restored %1$s" : "%2$s a restauré %1$s",
    "Changed by %2$s" : "Modifié par %2$s",
    "Deleted by %2$s" : "Supprimé par %2$s",
    "Restored by %2$s" : "Restauré par %2$s",
    "Upload (max. %s)" : "Envoi (max. %s)",
    "File handling" : "Gestion de fichiers",
    "Maximum upload size" : "Taille max. d'envoi",
    "max. possible: " : "Max. possible :",
    "Save" : "Sauvegarder",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Avec PHP-FPM il peut se passer jusqu'à 5 minutes pour que les changements soient appliqués.",
    "Missing permissions to edit from here." : "Manque de permissions pour éditer à partir d'ici.",
    "Settings" : "Paramètres",
    "Show hidden files" : "Afficher les fichiers cachés",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Utilisez cette adresse pour <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">accéder à vos fichiers par WebDAV</a>",
    "No files in here" : "Aucun fichier",
    "Upload some content or sync with your devices!" : "Déposez du contenu ou synchronisez vos appareils !",
    "No entries found in this folder" : "Aucune entrée trouvée dans ce dossier",
    "Select all" : "Tout sélectionner",
    "Upload too large" : "Téléversement trop volumineux",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Les fichiers que vous essayez d'envoyer dépassent la taille maximale d'envoi permise par ce serveur.",
    "No favorites" : "Aucun favori",
    "Files and folders you mark as favorite will show up here" : "Les fichiers et dossiers ajoutés à vos favoris apparaîtront ici",
    "Text file" : "Fichier texte",
    "New text file.txt" : "Nouveau fichier texte.txt",
    "Target folder does not exist any more" : "Le dossier cible n'existe plus",
    "Upload timeout for file \"{file}\"" : "Expiration du téléversement du fichier \"{file}\"",
    "Processing files..." : "Traitement des fichiers ...",
    "No entries in this folder match {filter}" : "Aucun fichier dans ce dossier ne correspond à {filter}",
    "Limit notifications about creation and changes to your <strong>favorite files</strong>" : "Limiter les notifications à la création ou la modification de vos <strong>fichiers favoris</strong>",
    "You don't have permissions to access this file/folder - Please contact the owner to share it with you." : "Vous n'êtes pas autorisé à accéder à ce fichier/dossier. Merci de contacter le propriétaire afin qu'il le partage avec vous.",
    "Error when assembling chunks, status code {status}" : "Erreur lors de l'assemblage d'un bloc, code {status}"
},
"nplurals=2; plural=(n > 1);");
